HilbertMCARotator
=================

.. currentmodule:: xeofs.cross

.. autoclass:: HilbertMCARotator
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HilbertMCARotator.__init__
      ~HilbertMCARotator.components
      ~HilbertMCARotator.components_amplitude
      ~HilbertMCARotator.components_phase
      ~HilbertMCARotator.compute
      ~HilbertMCARotator.correlation_coefficients_X
      ~HilbertMCARotator.correlation_coefficients_Y
      ~HilbertMCARotator.covariance_fraction_CD95
      ~HilbertMCARotator.cross_correlation_coefficients
      ~HilbertMCARotator.deserialize
      ~HilbertMCARotator.fit
      ~HilbertMCARotator.fraction_variance_X_explained_by_X
      ~HilbertMCARotator.fraction_variance_Y_explained_by_X
      ~HilbertMCARotator.fraction_variance_Y_explained_by_Y
      ~HilbertMCARotator.get_params
      ~HilbertMCARotator.get_serialization_attrs
      ~HilbertMCARotator.heterogeneous_patterns
      ~HilbertMCARotator.homogeneous_patterns
      ~HilbertMCARotator.inverse_transform
      ~HilbertMCARotator.load
      ~HilbertMCARotator.predict
      ~HilbertMCARotator.save
      ~HilbertMCARotator.scores
      ~HilbertMCARotator.scores_amplitude
      ~HilbertMCARotator.scores_phase
      ~HilbertMCARotator.serialize
      ~HilbertMCARotator.squared_covariance_fraction
      ~HilbertMCARotator.transform
   
   

   
   
   